@@ -19,6 +19,7 @@ pub struct StorageData {
     pub joined_rooms: Vec<RoomId>,
     pub room_id_to_cananoical_alias: BTreeMap<RoomId, RoomAliasId>,
     pub room_to_name: BTreeMap<RoomId, Box<RoomName>>,
+    pub room_to_direct_name: BTreeMap<RoomId, String>,
 }
 
 #[derive(Clone, Debug, Serialize, Deserialize, Default)]
@@ -444,6 +445,8 @@ impl Client {
                 //self.data.room_to_name.insert(room_id.clone(), self.room_id_to_alias[room_id.clone()]);
                 self.room_list_updated = true;
             }
+            let mut room_members: Vec<String> = Vec::new();
+            let mut is_direct = false;
             for event in joined_room.state.events.clone() {
                 //let ev = event.deserialize().unwrap();
                 if let Ok(ev) = event.deserialize() {
@@ -491,9 +494,26 @@ impl Client {
                                 .room_id_to_cananoical_alias
                                 .insert(room_id.clone(), alias);
                         }
+                    } else if let ruma::events::AnySyncStateEvent::RoomMember(room_member_event) =
+                        ev.clone()
+                    {
+                        if let Some(display_name) = room_member_event.content.displayname {
+                            room_members.push(display_name);
+                        }
+                        if let Some(direct) = room_member_event.content.is_direct {
+                            if !is_direct && direct == true {
+                                room_members.pop();
+                                is_direct = true;
+                            }
+                        }
                     }
                 }
             }
+            if is_direct {
+                self.data
+                    .room_to_direct_name
+                    .insert(room_id.clone(), room_members[0].clone());
+            }
             //if !event_args.starting {
             for message_info in joined_room.timeline.events.iter().filter_map(|m| {
                 if let Ok(ruma::events::AnySyncRoomEvent::Message(message_event)) =
